Terminal: for Simple and Beautiful
==================================

.. image:: https://travis-ci.org/lepture/terminal.png?branch=master
        :target: https://travis-ci.org/lepture/terminal

A better terminal tools for python.

Find documentation at `Read The Docs`_.

.. _`Read The Docs`: https://terminal.readthedocs.org/


Features
--------

* An easy to use command parser
* Full featured ANSI colors and styles
* Full featured prompt communcation
* Nested and verbose logging
* No dependencies (windows need colorama)

Installation
------------

To install terminal, simply::

    $ pip install terminal


Contribute
----------

Read the `Contribution Guide`_.

.. _`Contribution Guide`: https://github.com/lepture/terminal/blob/master/CONTRIBUTING.rst
